@@ -1,7 +1,6 @@
 # -*- coding: utf-8 -*-
 
 '''Wrappers for various units of text.'''
-from __future__ import unicode_literals
 import sys
 import json
 from collections import defaultdict
@@ -10,12 +9,13 @@ from .packages import nltk
 from .decorators import cached_property
 from .utils import lowerstrip, PUNCTUATION_REGEX
 from .inflect import singularize as _singularize, pluralize as _pluralize
-from .en import sentiment as _sentiment
 from .mixins import ComparableMixin
 from .compat import string_types, unicode
 from .np_extractors import BaseNPExtractor, FastNPExtractor
 from .taggers import BaseTagger, PatternTagger
 from .tokenizers import BaseTokenizer, WordTokenizer, SentenceTokenizer
+from .sentiments import BaseSentimentAnalyzer, PatternAnalyzer
+from .translate import Translator
 from .exceptions import MissingCorpusException
 
 
@@ -23,6 +23,8 @@ class Word(unicode):
 
     '''A simple word representation.'''
 
+    translator = Translator()
+
     def __new__(cls, string, pos_tag=None):
         '''Return a new instance of the class. It is necessary to override
         this method in order to handle the extra pos_tag argument in the
@@ -48,6 +50,22 @@ class Word(unicode):
         '''Return the plural version of the word as a string.'''
         return _pluralize(self.string)
 
+    def translate(self, from_lang="en", to="en"):
+        '''Translate the word to another language using Google's
+        Translate API.
+
+        New in `0.5.0`.
+        '''
+        return self.translator.translate(self.string,
+                                        from_lang=from_lang, to_lang=to)
+
+    def detect_language(self):
+        '''Detect the word's language using Google's Translate API.
+
+        New in `0.5.0`.
+        '''
+        return self.translator.detect(self.string)
+
 
 class WordList(list):
 
@@ -88,8 +106,7 @@ class WordList(list):
 
         Arguments:
         - s: The string to count.
-        - case_sensitive: A boolean, whether or not the search is
-                             case sensitive.
+        - case_sensitive: A boolean, whether or not the search is case-sensitive.
         """
         if not case_sensitive:
             return [word.lower() for word in self].count(strg.lower(), *args,
@@ -123,15 +140,19 @@ class BaseBlob(ComparableMixin):
     :param tokenizer: (optional) A tokenizer instance. If ``None``, defaults to :class:`WordTokenizer() <text.tokenizers.WordTokenizer>`.
     :param np_extractor: (optional) An NPExtractor instance. If ``None``, defaults to :class:`FastNPExtractor() <text.np_extractors.FastNPExtractor>`.
     :param pos_tagger: (optional) A Tagger instance. If ``None``, defaults to :class:`PatternTagger <text.taggers.PatternTagger>`.
+    :param analyzer: (optional) A sentiment analyzer. If ``None``, defaults to :class:`PatternAnalyzer` <text.sentiments.PatternAnalyzer>`.
     :param clean_html: (optional) Remove HTML markup from ``text``.
     '''
 
     np_extractor = FastNPExtractor()
     pos_tagger = PatternTagger()
     tokenizer = WordTokenizer()
+    translator = Translator()
+    analyzer = PatternAnalyzer()
 
     def __init__(self, text, tokenizer=None,
-                pos_tagger=None, np_extractor=None, clean_html=False):
+                pos_tagger=None, np_extractor=None, analyzer=None,
+                clean_html=False):
         if type(text) not in string_types:
             raise TypeError('The `text` argument passed to `__init__(text)` '
                             'must be a string, not {0}'.format(type(text)))
@@ -151,6 +172,10 @@ class BaseBlob(ComparableMixin):
                 not isinstance(pos_tagger, BaseTagger)):
             raise ValueError("pos_tagger must be an instance of BaseTagger")
         self.pos_tagger = pos_tagger if pos_tagger else BaseBlob.pos_tagger
+        if (analyzer is not None and
+                not isinstance(analyzer, BaseSentimentAnalyzer)):
+            raise ValueError("analyzer must be an instance of BaseSentimentAnalyzer")
+        self.analyzer = analyzer if analyzer else BaseBlob.analyzer
 
     @cached_property
     def words(self):
@@ -175,13 +200,33 @@ class BaseBlob(ComparableMixin):
         t = tokenizer if tokenizer is not None else self.tokenizer
         return WordList(t.tokenize(self.raw))
 
-    @property
+    @cached_property
     def sentiment(self):
-        '''Returns sentiment scores as a tuple of the form
-        `(polarity, subjectivity)` where polarity is in the range [-1.0, 1.0]
-        and subjectivity is in the range [0.0, 1.0].
+        '''Return a tuple of form (polarity, subjectivity ) where polarity
+        is a float within the range [-1.0, 1.0] and subjectivity is a float
+        within the range [0.0, 1.0] where 0.0 is very objective and 1.0 is
+        very subjective.
+
+        :rtype: tuple
         '''
-        return _sentiment(self.raw)
+        return self.analyzer.analyze(self.raw)
+
+    @cached_property
+    def polarity(self):
+        '''Return the polarity score as a float within the range [-1.0, 1.0]
+
+        :rtype: float
+        '''
+        return PatternAnalyzer().analyze(str(self))[0]
+
+    @cached_property
+    def subjectivity(self):
+        '''Return the subjectivity score as a float within the range [0.0, 1.0]
+        where 0.0 is very objective and 1.0 is very subjective.
+
+        :rtype: float
+        '''
+        return PatternAnalyzer().analyze(str(self))[1]
 
     @cached_property
     def noun_phrases(self):
@@ -192,16 +237,22 @@ class BaseBlob(ComparableMixin):
 
     @cached_property
     def pos_tags(self):
-        '''Returns an array of tuples of the form (word, POS tag).
+        '''Returns an list of tuples of the form (word, POS tag).
 
         Example:
+        ::
+
             [('At', 'IN'), ('eight', 'CD'), ("o'clock", 'JJ'), ('on', 'IN'),
                     ('Thursday', 'NNP'), ('morning', 'NN')]
+
+        :rtype: list of tuples
         '''
         return [(Word(word, pos_tag=t), unicode(t))
                 for word, t in self.pos_tagger.tag(self.raw)
                 if not PUNCTUATION_REGEX.match(unicode(t))]
 
+    tags = pos_tags
+
     @cached_property
     def word_counts(self):
         '''Dictionary of word frequencies in this text.
@@ -231,14 +282,62 @@ class BaseBlob(ComparableMixin):
                             for i in range(len(self.words) - n + 1)]
         return grams
 
+    def translate(self, from_lang="en", to="en"):
+        '''Translate the blob to another language.
+        Uses the Google Translate API. Returns a new TextBlob.
+
+        Requires an internet connection.
+
+        Usage:
+        ::
+
+            >>> b = TextBlob("Simple is better than complex")
+            >>> b.translate(to="es")
+            TextBlob('Lo simple es mejor que complejo')
+
+        Language code reference:
+            https://developers.google.com/translate/v2/using_rest#language-params
+
+        New in `0.5.0`.
+
+        :param from_lang: Language to translate from.
+        :param to: Language to translate to.
+        :rtype: Blob
+
+        '''
+        return self.__class__(self.translator.translate(self.raw,
+                        from_lang=from_lang, to_lang=to))
+
+    def detect_language(self):
+        '''Detect the blob's language using the Google Translate API.
+
+        Requires an internet connection.
+
+        Usage:
+        ::
+
+            >>> b = TextBlob("bonjour")
+            >>> b.detect_language()
+            u'fr'
+
+        Language code reference:
+            https://developers.google.com/translate/v2/using_rest#language-params
+
+        New in `0.5.0`.
+
+        :rtype: str
+
+        '''
+        return self.translator.detect(self.raw)
+
     def __repr__(self):
         '''Returns a string representation for debugging.'''
         class_name = self.__class__.__name__
-        if len(self) > 60:
-            return "{cls}('{beginning}...{end}')".format(cls=class_name,
-                    beginning=self.raw[:40], end=self.raw[-20:])
+        if len(self) > 100:
+            return unicode("{cls}('{beginning}...{end}')".format(cls=class_name,
+                    beginning=unicode(self)[:50], end=self.raw[-20:]))
         else:
-            return "{cls}('{text}')".format(cls=class_name, text=self.raw)
+            return unicode("{cls}('{text}')".format(cls=class_name, text=self.raw))
 
     def __len__(self):
         '''Returns the length of the raw text.'''
@@ -393,8 +492,10 @@ class TextBlob(BaseBlob):
     containing sentences). Inherits from :class:`BaseBlob <BaseBlob>`.
 
     :param text: A string.
+    :param tokenizer: (optional) A tokenizer instance. If ``None``, defaults to :class:`WordTokenizer() <text.tokenizers.WordTokenizer>`.
     :param np_extractor: (optional) An NPExtractor instance. If ``None``, defaults to :class:`FastNPExtractor() <text.np_extractors.FastNPExtractor>`.
     :param pos_tagger: (optional) A Tagger instance. If ``None``, defaults to :class:`PatternTagger <text.taggers.PatternTagger>`.
+    :param analyzer: (optional) A sentiment analyzer. If ``None``, defaults to :class:`PatternAnalyzer` <text.sentiments.PatternAnalyzer>`.
     :param clean_html: (optional) Remove HTML markup from ``text``.
     """
 
@@ -502,7 +603,8 @@ class Sentence(BaseBlob):
             'end_index': self.end_index,
             'stripped': self.stripped,
             'noun_phrases': self.noun_phrases,
-            'sentiment': self.sentiment,
+            'polarity': self.polarity,
+            'subjectivity': self.subjectivity,
         }
 
 class Blobber(object):
@@ -524,13 +626,16 @@ class Blobber(object):
     :param tokenizer: A tokenizer. Default: :class:`WordTokenizer <text.tokenizers.WordTokenizer>`.
     :param pos_tagger: A POS tagger. Default: :class:`PatternTagger <text.taggers.PatternTagger>`.
     :param np_extractor: A NP extractor. Default: :class:`FastNPExtractor <text.np_extractors.FastNPExtractor>`.
+    :param analyzer: (optional) A sentiment analyzer. If ``None``, defaults to :class:`PatternAnalyzer` <text.sentiments.PatternAnalyzer>`.
     '''
 
     np_extractor = FastNPExtractor()
     pos_tagger = PatternTagger()
     tokenizer = WordTokenizer()
+    analyzer = PatternAnalyzer()
 
-    def __init__(self, tokenizer=None, pos_tagger=None, np_extractor=None):
+    def __init__(self, tokenizer=None, pos_tagger=None, np_extractor=None,
+                analyzer=None):
         # tokenizer may be a textblob or an NLTK tokenizer
         if (tokenizer is not None and
                 not (isinstance(tokenizer, BaseTokenizer) or
@@ -545,13 +650,29 @@ class Blobber(object):
                 not isinstance(pos_tagger, BaseTagger)):
             raise ValueError("pos_tagger must be an instance of BaseTagger")
         self.pos_tagger = pos_tagger if pos_tagger else Blobber.pos_tagger
+        if (analyzer is not None and
+                not isinstance(analyzer, BaseSentimentAnalyzer)):
+            raise ValueError("analyzer must be an instance of BaseSentimentAnalyzer")
+        self.analyzer = analyzer if analyzer else BaseBlob.analyzer
 
     def __call__(self, text):
         '''Return a new TextBlob object with this Blobber's ``np_extractor``,
         ``pos_tagger``, and ``tokenizer``.
+
+        :returns: A new TextBlob.
         '''
         return TextBlob(text, tokenizer=self.tokenizer, pos_tagger=self.pos_tagger,
-            np_extractor=self.np_extractor)
+            np_extractor=self.np_extractor, analyzer=self.analyzer)
+
+    def __repr__(self):
+        return ("Blobber(tokenizer={0}(), pos_tagger={1}(), "
+                    "np_extractor={2}(), analyzer={3}())")\
+                    .format(self.tokenizer.__class__.__name__,
+                            self.pos_tagger.__class__.__name__,
+                            self.np_extractor.__class__.__name__,
+                            self.analyzer.__class__.__name__)
+
+    __str__ = __repr__
 
 
 
