@@ -1,9 +1,12 @@
+# -*- coding: utf-8 -*-
 import sys
 
 PY2 = int(sys.version[0]) == 2
 
 if PY2:
     from itertools import imap
+    import urllib2 as request
+    from urllib import quote as urlquote
     text_type = unicode
     binary_type = str
     string_types = (str, unicode)
@@ -11,9 +14,11 @@ if PY2:
     basestring = basestring
     imap = imap
 else:
+    from urllib import request
+    from urllib.parse import quote as urlquote
     text_type = str
     binary_type = bytes
     string_types = (str,)
     unicode = str
-    basestring = str
+    basestring = (str, bytes)
     imap = map
